function TrtPlot
% TrtPlot  Plot T(r,t) for a sphere with Bi>0.1 and a range of Fourier numbers

% -- Define Bi (scalar) and Fo (vector), then compute T(t,r)
Bi = 10;
Fomin = 0.0;
Fomax = 0.5;
Fo = linspace(Fomin,Fomax);
[T,rstar] = Tsphere(Bi,Fo,25);   %  Real work is done by Tsphere

% -- Overwrite initial time with initial condition.  This eliminates any error
%    in the infinite series solution, which is likely to be largest at t=0
nr = size(T,1);        %  number of radial positions
T(:,1) = ones(nr,1);   %  First column of T is initial condition

%  --- Plot T(t,r) at selected times
figure('Name','Radial temperature distribution');
it1 = 1;
it2 = find(Fo<0.1,1,'last');     % index in Fo for Fo approx equal to 0.1
it3 = find(Fo<0.2,1,'last');     % index in Fo for Fo approx equal to 0.2
plot(rstar,T(:,it1),'--',rstar,T(:,it2),'-',rstar,T(:,it3),'-.');
title(sprintf('Radial temperature distribution for Bi = %4.1f',Bi));
xlabel('Dimensionless radial position');
ylabel('\theta','FontSize',16,'Rotation',0);
axis([0 1 0 1.1]);

% --- Locate labels on the plot:  this is hand work!
xtext = 0.5;
ytext = 0.94;
text(xtext,ytext,sprintf('Fo = %5.2f',Fo(it1)));

ir = find(rstar>0.6,1,'first');  %  index in rstar for rstar approx equal to 0.6
xtext = 1.1*rstar(ir);
ytext = 1.1*T(ir,it2);
text(xtext,ytext,sprintf('Fo = %5.2f',Fo(it2)));

ir = find(rstar>0.1,1,'first');  %  index in rstar for rstar approx equal to 0.1
xtext = 1.1*rstar(ir);
ytext = 1.1*T(ir,it3);
text(xtext,ytext,sprintf('Fo = %5.2f',Fo(it3)));

% --- Plot T(t) at center and at surface
figure('Name','Transient centerline temperature');
plot(Fo,T(1,:),'--',Fo,T(nr,:),'-');
title(sprintf('Temperature history at center and surface of sphere for Bi = %4.1f',Bi));
xlabel('Fo   dimensionless time');
ylabel('\theta','FontSize',16,'Rotation',0);
axis([0 Fomax 0 1.1]);

% --- Locate labels on the plot:  this is hand work!
it = find(Fo>0.2,1,'first');
xtext = 1.1*Fo(it);
ytext = 1.1*T(1,it);
text(xtext,ytext,'Center temperature');

it = find(Fo>0.05,1,'first');  %  index in Fo for Fo approx equal to 0.05
xtext = 1.1*Fo(it);
ytext = 1.1*T(nr,it);
text(xtext,ytext,'Surface temperature');

end
