function sphereExample
% sphereExample  T(r,t) for a metal sphere plunged into a water bath

% --- Specify constants
h = 6000;        %  heat transfer coefficent,  W/m^2/C
k = 20;          %  thermal conductivity,  W/m/K
alfa = 6.66e-6;  %  thermal diffusivity,  m^2/s
ro = 5e-3;       %  radius of sphere,  m
tmax = 5;        %  stop time, s

r = linspace(0,ro);
t = linspace(0,tmax);

% --- Compute theta at center and at the surface of the sphere.
%     Characteristic length is r0 for the exact solution.
Bi = h*ro/k
Fo = alfa*t/ro^2;
theta = Tsphere(Bi,Fo,2);  %  nr = 2 for r*=1 and r*=1

% --- Convert to temperature and plot
Ti = 400;   Tinf = 50;
T = Tinf + theta*(Ti-Tinf);
plot(t,T(1,:),'b-',t,T(2,:),'r--',[0 max(t)],[Tinf Tinf],'k:');
axis([0 max(t) 20 Ti+20]);
xlabel('Time (sec)');    ylabel('T  ({}^\circ C)');
legend('Center','Surface','Oil bath','Location','NorthEast');

% --- Evaluate and plot the radial temperatures at t=0.5, 1, 5
t = [0.5 1 5]
Fo = alfa*t/ro^2;
[theta,rstar] = Tsphere(Bi,Fo,50);
T = Tinf + theta*(Ti-Tinf);
rmm = 1000*rstar*ro;
figure
plot(rmm,T(:,1),'k-',rmm,T(:,2),'b--',rmm,T(:,3),'r-.',...
     [0 max(t)],[Tinf Tinf],'k:');
legend('t = 0.5 sec','t = 1 sec','t = 5 sec','Oil bath','Location','NorthEast');
xlabel('r (mm)');    ylabel('T  ({}^\circ C)');
axis([0 max(rmm) 20 Ti+20]);

end
